@@ -3,9 +3,11 @@ from insider.config import Port
 LOWER_LIMIT = 10000
 UPPER_LIMIT = 65535
 
+
 def find_available_port(existing_ports):
     return next(x for x in range(LOWER_LIMIT, UPPER_LIMIT) if not x in existing_ports)
 
+
 class PortMapper:
 
     def __init__(self, port_config, upnpc):
@@ -45,6 +47,6 @@ class PortMapper:
                     self.upnpc.remove(port)
                 if first_external_port != mapping.external_port:
                     mapping.external_port = first_external_port
-                    self.port_config.update_port(mapping)
+                    self.port_config.update(mapping)
             else:
                 self.add(mapping.local_port)
\ No newline at end of file
